@@ -1,4 +1,5 @@
 import os
+import sys
 from inspect import getsource
 from tempfile import TemporaryDirectory
 from typing import Any, Callable, Dict, List, Optional, Union
@@ -6,7 +7,17 @@ from zipfile import ZipFile
 
 from cognite.client import utils
 from cognite.client._api_client import APIClient
-from cognite.experimental.data_classes import Function, FunctionCall, FunctionCallList, FunctionCallLog, FunctionList
+from cognite.experimental.data_classes import (
+    Function,
+    FunctionCall,
+    FunctionCallList,
+    FunctionCallLog,
+    FunctionList,
+    FunctionSchedule,
+    FunctionSchedulesList,
+)
+
+HANDLER_FILE_NAME = "handler.py"
 
 
 class FunctionsAPI(APIClient):
@@ -16,6 +27,7 @@ class FunctionsAPI(APIClient):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.calls = FunctionCallsAPI(*args, **kwargs)
+        self.schedules = FunctionSchedulesAPI(*args, **kwargs)
 
     def create(
         self,
@@ -34,7 +46,7 @@ class FunctionsAPI(APIClient):
         Args:
             name (str):                             The name of the function.
             folder (str, optional):                 Path to the folder where the function source code is located.
-            filde_id (int, optional):               File ID of the code uploaded to the Files API.
+            file_id (int, optional):                File ID of the code uploaded to the Files API.
             function_handle (Callable, optional):   Reference to a function object, which must be named `handle`. Valid arguments to `handle` are `data`, `client` and `secret`.
             external_id (str, optional):            External id of the function.
             description (str, optional):            Description of the function.
@@ -68,9 +80,10 @@ class FunctionsAPI(APIClient):
         self._assert_exactly_one_of_folder_or_file_id_or_function_handle(folder, file_id, function_handle)
 
         if folder:
+            validate_function_folder(folder)
             file_id = self._zip_and_upload_folder(folder, name)
         elif function_handle:
-            self._validate_function_handle(function_handle)
+            _validate_function_handle(function_handle)
             file_id = self._zip_and_upload_handle(function_handle, name)
 
         url = "/functions"
@@ -110,7 +123,7 @@ class FunctionsAPI(APIClient):
 
         Returns:
             FunctionList: List of functions
-        
+
         Example:
 
             List functions::
@@ -185,15 +198,15 @@ class FunctionsAPI(APIClient):
         id: Optional[int] = None,
         external_id: Optional[str] = None,
         data: Optional[Dict] = None,
-        asynchronous: bool = False,
+        wait: bool = True,
     ) -> FunctionCall:
-        """Call a function by its ID or external ID. Can be done `synchronously <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-function_name-call>`_ or `asynchronously <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-functionId-async_call>`_.
+        """Call a function by its ID or external ID. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-function_name-call>`_.
 
         Args:
             id (int, optional): ID
             external_id (str, optional): External ID
             data (Union[str, dict], optional): Input data to the function (JSON serializable). This data is passed deserialized into the function through one of the arguments called data.
-            asynchronous (bool): Call the function asynchronously. Defaults to false.
+            wait (bool): Wait until the function call is finished. Defaults to True.
 
         Returns:
             FunctionCall: A function call object.
@@ -217,14 +230,22 @@ class FunctionsAPI(APIClient):
         if external_id:
             id = self.retrieve(external_id=external_id).id
 
-        url = f"/functions/{id}/call" if not asynchronous else f"/functions/{id}/async_call"
+        url = f"/functions/{id}/call"
         body = {}
         if data:
             body = {"data": data}
         res = self._post(url, json=body)
-        return FunctionCall._load(res.json(), function_id=id, cognite_client=self._cognite_client)
+        function_call = FunctionCall._load(res.json(), function_id=id, cognite_client=self._cognite_client)
+
+        if wait:
+            function_call.wait()
+
+        return function_call
 
     def _zip_and_upload_folder(self, folder, name) -> int:
+        # / is not allowed in file names
+        name = name.replace("/", "-")
+
         current_dir = os.getcwd()
         os.chdir(folder)
 
@@ -246,15 +267,18 @@ class FunctionsAPI(APIClient):
             os.chdir(current_dir)
 
     def _zip_and_upload_handle(self, function_handle, name) -> int:
+        # / is not allowed in file names
+        name = name.replace("/", "-")
+
         with TemporaryDirectory() as tmpdir:
-            handle_path = os.path.join(tmpdir, "handler.py")
+            handle_path = os.path.join(tmpdir, HANDLER_FILE_NAME)
             with open(handle_path, "w") as f:
                 source = getsource(function_handle)
                 f.write(source)
 
             zip_path = os.path.join(tmpdir, "function.zip")
             zf = ZipFile(zip_path, "w")
-            zf.write(handle_path, arcname="handler.py")
+            zf.write(handle_path, arcname=HANDLER_FILE_NAME)
             zf.close()
 
             file = self._cognite_client.files.upload(zip_path, name=f"{name}.zip")
@@ -274,16 +298,37 @@ class FunctionsAPI(APIClient):
                 + " were given."
             )
 
-    @staticmethod
-    def _validate_function_handle(function_handle):
-        if not function_handle.__code__.co_name == "handle":
-            raise TypeError("Function referenced by function_handle must be named handle.")
-        if not set(function_handle.__code__.co_varnames[: function_handle.__code__.co_argcount]).issubset(
-            set(["data", "client", "secrets"])
-        ):
-            raise TypeError(
-                "Arguments to function referenced by function_handle must be a subset of (data, client, secrets)"
-            )
+
+def validate_function_folder(path):
+    sys.path.insert(0, path)
+    if HANDLER_FILE_NAME not in os.listdir(path):
+        sys.path.remove(path)
+        raise TypeError(f"Function folder must contain a module named {HANDLER_FILE_NAME}.")
+
+    cached_handler_module = sys.modules.get("handler")
+    if cached_handler_module:
+        del sys.modules["handler"]
+    import handler
+
+    if "handle" not in handler.__dir__():
+        sys.path.remove(path)
+        raise TypeError(f"{HANDLER_FILE_NAME} must contain a function named 'handle'.")
+
+    _validate_function_handle(handler.handle)
+    sys.path.remove(path)
+    if cached_handler_module:
+        sys.modules["handler"] = cached_handler_module
+
+
+def _validate_function_handle(function_handle):
+    if not function_handle.__code__.co_name == "handle":
+        raise TypeError("Function referenced by function_handle must be named handle.")
+    if not set(function_handle.__code__.co_varnames[: function_handle.__code__.co_argcount]).issubset(
+        set(["data", "client", "secrets"])
+    ):
+        raise TypeError(
+            "Arguments to function referenced by function_handle must be a subset of (data, client, secrets)"
+        )
 
 
 class FunctionCallsAPI(APIClient):
@@ -292,11 +337,11 @@ class FunctionCallsAPI(APIClient):
 
         Args:
             function_id (int, optional): ID of the function on which the calls were made.
-            external_id (str, optional): External ID of the function on which the calls were made.
+            function_external_id (str, optional): External ID of the function on which the calls were made.
 
         Returns:
             FunctionCallList: List of function calls
-        
+
         Examples:
 
             List function calls::
@@ -332,7 +377,7 @@ class FunctionCallsAPI(APIClient):
 
         Returns:
             FunctionCall: Function call.
-        
+
         Examples:
 
             Retrieve function call by id::
@@ -368,7 +413,7 @@ class FunctionCallsAPI(APIClient):
 
         Returns:
             FunctionCallLog: Log for the function call.
-        
+
         Examples:
 
             Retrieve function call logs by call ID::
@@ -391,3 +436,96 @@ class FunctionCallsAPI(APIClient):
         url = f"/functions/{function_id}/calls/{call_id}/logs"
         res = self._get(url)
         return FunctionCallLog._load(res.json()["items"])
+
+
+class FunctionSchedulesAPI(APIClient):
+    def list(self) -> FunctionSchedulesList:
+        """`List all schedules associated with a specific project. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-schedules>`_
+
+        Returns:
+            FunctionSchedulesList: List of function schedules
+
+        Examples:
+
+            List function schedules::
+
+                >>> from cognite.experimental import CogniteClient
+                >>> c = CogniteClient()
+                >>> schedules = c.functions.schedules.list()
+
+        """
+        url = f"/functions/schedules"
+        res = self._get(url)
+        return FunctionSchedulesList._load(res.json()["items"])
+
+    def create(
+        self,
+        name: str,
+        function_external_id: str,
+        cron_expression: str,
+        description: str = "",
+        data: Optional[Dict] = None,
+    ) -> FunctionSchedule:
+        """`Create a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-schedules>`_
+
+        Args:
+            name (str): Name of the schedule.
+            function_external_id (str): External id of the function.
+            description (str): Description of the schedule.
+            cron_expression (str): Cron expression.
+            data (optional, Dict): Data to be passed to the scheduled run.
+
+        Returns:
+            FunctionSchedule: Created function schedule.
+
+        Examples:
+
+            Create function schedule::
+
+                >>> from cognite.experimental import CogniteClient
+                >>> c = CogniteClient()
+                >>> schedule = c.functions.schedules.create(
+                    name= "My schedule",
+                    function_external_id="my-external-id",
+                    cron_expression="*/5 * * * *",
+                    description="This schedule does magic stuff.")
+
+        """
+        json = {
+            "items": [
+                {
+                    "name": name,
+                    "description": description,
+                    "functionExternalId": function_external_id,
+                    "cronExpression": cron_expression,
+                }
+            ]
+        }
+        if data:
+            json["items"][0]["data"] = data
+
+        url = f"/functions/schedules"
+        res = self._post(url, json=json)
+        return FunctionSchedule._load(res.json()["items"][0])
+
+    def delete(self, id: int) -> None:
+        """`Delete a schedule associated with a specific project. <https://docs.cognite.com/api/playground/#operation/post-api-playground-projects-project-functions-schedules-delete>`_
+
+        Args:
+            id (int): Id of the schedule
+
+        Returns:
+            None
+
+        Examples:
+
+            Delete function schedule::
+
+                >>> from cognite.experimental import CogniteClient
+                >>> c = CogniteClient()
+                >>> c.functions.schedules.delete(id = 123)
+
+        """
+        json = {"items": [{"id": id,}]}
+        url = f"/functions/schedules/delete"
+        self._post(url, json=json)
