@@ -2,17 +2,20 @@ import os
 from typing import Callable, Dict, Optional, Union
 
 from cognite.client._api.datapoints import DatapointsAPI
+from cognite.client._api.files import FilesAPI
 from cognite.client._cognite_client import CogniteClient as Client
 from cognite.experimental._api.assets import ExperimentalAssetsAPI
 from cognite.experimental._api.entity_extraction import EntityExtractionAPI
 from cognite.experimental._api.entity_matching import EntityMatchingAPI
 from cognite.experimental._api.functions import FunctionsAPI
+from cognite.experimental._api.labels import LabelsAPI
 from cognite.experimental._api.model_hosting import ModelHostingAPI
 from cognite.experimental._api.pnid_parsing import PNIDParsingAPI
 from cognite.experimental._api.relationships import RelationshipsAPI
 from cognite.experimental._api.resource_typing import ResourceTypingAPI
 from cognite.experimental._api.synthetic_time_series import SyntheticDatapointsAPI
 from cognite.experimental._api.types import TypesAPI
+from cognite.experimental._api.unstructured import GrepAPI
 
 
 class ExperimentalDatapointsApi(DatapointsAPI):
@@ -21,6 +24,12 @@ class ExperimentalDatapointsApi(DatapointsAPI):
         self.synthetic = SyntheticDatapointsAPI(self._config, api_version="playground", cognite_client=self)
 
 
+class ExperimentalFilesApi(FilesAPI):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.unstructured = GrepAPI(self._config, api_version="playground", cognite_client=self)
+
+
 class CogniteClient(Client):
     """Initializes cognite client, with experimental extensions.
 
@@ -73,10 +82,12 @@ class CogniteClient(Client):
         )
         self.relationships = RelationshipsAPI(self._config, api_version="playground", cognite_client=self)
         self.datapoints = ExperimentalDatapointsApi(self._config, api_version="v1", cognite_client=self)
+        self.files = ExperimentalFilesApi(self._config, api_version="v1", cognite_client=self)
         self.model_hosting = ModelHostingAPI(self._config, api_version="playground", cognite_client=self)
 
         self.assets_playground = ExperimentalAssetsAPI(self._config, api_version="playground", cognite_client=self)
         self.types = TypesAPI(self._config, api_version="playground", cognite_client=self)
+        self.labels = LabelsAPI(self._config, api_version="playground", cognite_client=self)
 
         self.entity_matching = EntityMatchingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_extraction = EntityExtractionAPI(self._config, api_version="playground", cognite_client=self)
