@@ -1,4 +1,6 @@
 from cognite.experimental.data_classes.assets import *
 from cognite.experimental.data_classes.contextualization import *
+from cognite.experimental.data_classes.functions import *
+from cognite.experimental.data_classes.labels import *
 from cognite.experimental.data_classes.relationships import *
 from cognite.experimental.data_classes.types import *
