@@ -1,3 +1,4 @@
+import time
 from typing import Dict, List, Union
 
 from cognite.client.data_classes._base import CogniteResource, CogniteResourceList
@@ -17,6 +18,7 @@ class Function(CogniteResource):
         created_time (int): Created time in UNIX.
         api_key (str): Api key attached to the function.
         secrets (Dict[str, str]): Secrets attached to the function ((key, value) pairs).
+        error(Dict[str, str]): Dictionary with keys "message" and "trace", which is populated if deployment fails.
         cognite_client (CogniteClient): An optional CogniteClient to associate with this data class.
     """
 
@@ -32,6 +34,7 @@ class Function(CogniteResource):
         created_time: int = None,
         api_key: str = None,
         secrets: Dict = None,
+        error: Dict = None,
         cognite_client=None,
     ):
         self.id = id
@@ -44,6 +47,7 @@ class Function(CogniteResource):
         self.created_time = created_time
         self.api_key = api_key
         self.secrets = secrets
+        self.error = error
         self._cognite_client = cognite_client
 
     def call(self, data=None, asynchronous: bool = False):
@@ -52,10 +56,55 @@ class Function(CogniteResource):
     def list_calls(self):
         return self._cognite_client.functions.calls.list(function_id=self.id)
 
+    def list_schedules(self):
+        all_schedules = self._cognite_client.functions.schedules.list()
+        function_schedules = filter(lambda f: f.function_external_id == self.external_id, all_schedules)
+        return list(function_schedules)
+
     def retrieve_call(self, id: int):
         return self._cognite_client.functions.calls.retrieve(call_id=id, function_id=self.id)
 
 
+class FunctionSchedule(CogniteResource):
+    """A representation of a Cognite Function Schedule.
+
+    Args:
+        id (int): Id of the schedule.
+        name (str): Name of the function schedule.
+        function_external_id (str): External id of the function.
+        description (str): Description of the function schedule.
+        cron_expression (str): Cron expression
+        created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
+        data (Dict): Data to be passed to the scheduled run.
+        cognite_client (CogniteClient): An optional CogniteClient to associate with this data class.
+    """
+
+    def __init__(
+        self,
+        id: int = None,
+        name: str = None,
+        function_external_id: str = None,
+        description: str = None,
+        created_time: int = None,
+        cron_expression: str = None,
+        data: Dict = None,
+        cognite_client=None,
+    ):
+        self.id = id
+        self.name = name
+        self.function_external_id = function_external_id
+        self.description = description
+        self.cron_expression = cron_expression
+        self.created_time = created_time
+        self.data = data
+        self._cognite_client = cognite_client
+
+
+class FunctionSchedulesList(CogniteResourceList):
+    _RESOURCE = FunctionSchedule
+    _ASSERT_CLASSES = False
+
+
 class FunctionList(CogniteResourceList):
     _RESOURCE = Function
     _ASSERT_CLASSES = False
@@ -68,7 +117,7 @@ class FunctionCall(CogniteResource):
         id (int): A server-generated ID for the object.
         start_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
         end_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
-        response (str): Response from the function. The function must return a JSON serializable object.
+        response (str): Response from the function. The function must return a JSON serializable object or nothing.
         status (str): Status of the function call ("Running" or "Completed").
         error (dict): Error from the function call. It contains an error message and the stack trace.
         cognite_client (CogniteClient): An optional CogniteClient to associate with this data class.
@@ -97,6 +146,18 @@ class FunctionCall(CogniteResource):
     def get_logs(self):
         return self._cognite_client.functions.calls.get_logs(call_id=self.id, function_id=self._function_id)
 
+    def update(self):
+        latest = self._cognite_client.functions.calls.retrieve(call_id=self.id, function_id=self._function_id)
+        self.status = latest.status
+        self.end_time = latest.end_time
+        self.response = latest.response
+        self.error = latest.error
+
+    def wait(self):
+        while self.status == "Running":
+            self.update()
+            time.sleep(1.0)
+
     @classmethod
     def _load(cls, resource: Union[Dict, str], function_id: int = None, cognite_client=None):
         instance = super()._load(resource, cognite_client=cognite_client)
